@@ -536,7 +536,13 @@ class ModManagementScreen private constructor(
         val newModUIData = ModUIData(ruleset, isVisual)
         installedModInfo[modName] = newModUIData
         // The ModUIData in the actual button is now out of sync, but can be indexed using the new instance
-        modButtons[newModUIData]?.updateUIData(newModUIData)
+        modButtons[newModUIData]?.run {
+            updateUIData(newModUIData)
+            // The listeners have also captured a now outdated ModUIData
+            setModButtonOnClick(this, newModUIData)
+            // Simulate click to update the ModInfoAndActionPane
+            installedButtonAction(newModUIData, this)
+        }
     }
 
     /** Remove the visual indicators for an 'updated' mod after re-downloading it.
@@ -605,10 +611,13 @@ class ModManagementScreen private constructor(
 
     private fun getCachedModButton(mod: ModUIData) = modButtons.getOrPut(mod) {
         val newButton = ModDecoratedButton(mod)
-        if (mod.isInstalled) newButton.onClick { installedButtonAction(mod, newButton) }
-        else newButton.onClick { onlineButtonAction(mod.repo!!, newButton) }
+        setModButtonOnClick(newButton, mod)
         newButton
     }
+    private fun setModButtonOnClick(button: ModDecoratedButton, mod: ModUIData) {
+        if (mod.isInstalled) button.onClick { installedButtonAction(mod, button) }
+        else button.onClick { onlineButtonAction(mod.repo!!, button) }
+    }
 
     /** Rebuild the left-hand column containing all installed mods */
     internal fun refreshInstalledModTable() {
@@ -655,6 +664,7 @@ class ModManagementScreen private constructor(
         mod.folderLocation!!.deleteDirectory()
         reloadCachesAfterModChange()
         installedModInfo.remove(mod.name)
+        unMarkUpdatedMod(mod.name)
         refreshInstalledModTable()
     }
 
@@ -690,6 +700,7 @@ class ModManagementScreen private constructor(
         scrollOnlineMods.actor = onlineModsTable
     }
 
+    /** Updates the description label at the bottom of the screen */
     private fun showModDescription(modName: String) {
         val onlineModDescription = onlineModInfo[modName]?.description ?: "" // shows github info
         val installedModDescription = installedModInfo[modName]?.description ?: "" // shows ruleset info
